@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2017, Met Office
+# (C) British Crown Copyright 2010 - 2020, Met Office
 #
 # This file is part of Iris.
 #
@@ -60,7 +60,7 @@ def _mock_gribapi_fetch(message, key):
     if key in message:
         return message[key]
     else:
-        raise _mock_gribapi.GribInternalError
+        raise _mock_gribapi.errors.GribInternalError
 
 
 def _mock_gribapi__grib_is_missing(grib_message, keyname):
@@ -83,13 +83,13 @@ def _mock_gribapi__grib_get_native_type(grib_message, keyname):
     """
     if keyname in grib_message:
         return type(grib_message[keyname])
-    raise _mock_gribapi.GribInternalError(keyname)
+    raise _mock_gribapi.errors.GribInternalError(keyname)
 
 
 if tests.GRIB_AVAILABLE:
     # Construct a mock object to mimic the gribapi for GribWrapper testing.
     _mock_gribapi = mock.Mock(spec=gribapi)
-    _mock_gribapi.GribInternalError = Exception
+    _mock_gribapi.errors.GribInternalError = Exception
 
     _mock_gribapi.grib_get_long = mock.Mock(side_effect=_mock_gribapi_fetch)
     _mock_gribapi.grib_get_string = mock.Mock(side_effect=_mock_gribapi_fetch)
