@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2019, Met Office
+# (C) British Crown Copyright 2010 - 2020, Met Office
 #
 # This file is part of Iris.
 #
@@ -915,6 +915,67 @@ class _OrderedHashable(six.with_metaclass(_MetaOrderedHashable,
             return NotImplemented
 
 
+def _array_slice_ifempty(keys, shape, dtype):
+    """
+    Detect cases where an array slice will contain no data, as it contains a
+    zero-length dimension, and produce an equivalent result for those cases.
+
+    The function indicates 'empty' slicing cases, by returning an array equal
+    to the slice result in those cases.
+
+    Args:
+
+    * keys (indexing key, or tuple of keys):
+        The argument from an array __getitem__ call.
+        Only tuples of integers and slices are supported, in particular no
+        newaxis, ellipsis or array keys.
+        These are the types of array access usage we expect from Dask.
+    * shape (tuple of int):
+        The shape of the array being indexed.
+    * dtype (numpy.dtype):
+        The dtype of the array being indexed.
+
+    Returns:
+        result (np.ndarray or None):
+            If 'keys' contains a slice(0, 0), this is an ndarray of the correct
+            resulting shape and provided dtype.
+            Otherwise it is None.
+
+    .. note::
+
+        This is used to prevent DataProxy arraylike objects from fetching their
+        file data when wrapped as Dask arrays.
+        This is because, for Dask >= 2.0, the "dask.array.from_array" call
+        performs a fetch like [0:0, 0:0, ...], to 'snapshot' array metadata.
+        This function enables us to avoid triggering a file data fetch in those
+        cases :  This is consistent because the result will not contain any
+        actual data content.
+
+    """
+    # Convert a single key into a 1-tuple, so we always have a tuple of keys.
+    if isinstance(keys, tuple):
+        keys_tuple = keys
+    else:
+        keys_tuple = (keys,)
+
+    if any(key == slice(0, 0) for key in keys_tuple):
+        # An 'empty' slice is present :  Return a 'fake' array instead.
+        target_shape = list(shape)
+        for i_dim, key in enumerate(keys_tuple):
+            if key == slice(0, 0):
+                # Reduce dims with empty slicing to length 0.
+                target_shape[i_dim] = 0
+        # Create a prototype result : no memory usage, as some dims are 0.
+        result = np.zeros(target_shape, dtype=dtype)
+        # Index with original keys to produce the desired result shape.
+        # Note : also ok in 0-length dims, as the slice is always '0:0'.
+        result = result[keys]
+    else:
+        result = None
+
+    return result
+
+
 def create_temp_filename(suffix=''):
     """Return a temporary file name.
 
